arete_setup: Setup arete

View source: R/01_arete_setup.R

arete_setupR Documentation

Setup arete

Description

arete requires python to use most of its LLM utilities. OCR utilities will by default not be installed as they are not strictly necessary to the usage of the package. If interested please see install_OCR_packages(). We recommend that you install Python before running arete_setup. Usually performed through sudo apt install python3-venv python3-pip python3-dev on linux systems or reticulate::install_python() for other OS. Some external software might also be needed to successfully install arete's dependencies, including:

  • GDAL, GEOS, PROJ, netcdf, sqlite3, tbb, see rspatial.github.io/terra

  • poppler (rpm: poppler-cpp-devel (Fedora, CentOS, RHEL), brew: poppler (MacOS) )

  • kableExtra (fontconfig, deb:libfontconfig1-dev (Debian, Ubuntu, etc), rpm: fontconfig-devel (Fedora, EPEL), csw: fontconfig_dev (Solaris), brew: freetype (OSX) )

  • cmake

With some being covered by r-base-dev:

  • gfortran, libgmp3-dev,

  • harfbuzz freetype2 fribidi (deb:libharfbuzz-dev libfribidi-dev (Debian, Ubuntu, etc), rpm: harfbuzz-devel fribidi-devel (Fedora, EPEL), brew: harfbuzz fribidi (OSX) )

Usage

arete_setup(python = NULL)

Arguments

python

character. Path to a python virtual environment in which to use arete.

Details

A custom virtual environment path may be passed to python but we recommend leaving it as NULL and using one of the paths found by reticulate. It is however useful if arete is already setup and you just wish to update its dependencies.

Value

character. Python path to the virtual environment created.

Examples

## Not run: 
arete_setup()

## End(Not run)

arete documentation built on Nov. 5, 2025, 6:31 p.m.