aux_string_to_coords: Mechanical coordinate conversion

View source: R/00_auxiliary_functions.R

aux_string_to_coordsR Documentation

Mechanical coordinate conversion

Description

Mechanically convert character strings containing geographic coordinates and convert to sets of numeric values. Useful as most LLM experience better and more consistent results when asked to return a single string instead of two separate values.

Usage

aux_string_to_coords(coord_string)

Arguments

coord_string

character. A string containg potential geographic coordinates.

Details

Will convert all strings to N, W for consistency's sake. Future updates will probably make it a toggle.

Value

list. Contain latitude and longitude as the first and second elements, respectively.

Examples

example = "19 ° 34 ’ S 29 ° 10 ° E"
aux_string_to_coords(example)

arete documentation built on Nov. 5, 2025, 6:31 p.m.