View source: R/02_create_training_data.R
| create_training_data | R Documentation |
Open WebAnnoTSV files following RECODE structure and build training data for large language models in a variety of formats.
create_training_data(
input,
prompt = NULL,
service = "GPT",
aggregate = TRUE,
export_type = "jsonl",
out_path = NULL
)
input |
character or list. Either a set of paths to WebAnno TSV 3.3 files from which the text and annotated data are taken or a list with two terms,
1) paths to |
prompt |
character. Custom prompt to be attached to each |
service |
character. Service to be used. Right now, only |
aggregate |
boolean. If TRUE and prompt is |
export_type |
character. Either |
out_path |
character. Path to where the training data will be saved. |
matrix / data.frame
example = system.file(paste0("extdata/insecta_annot_1.tsv"), package = "arete")
create_training_data(input = example, service = "GPT", export_type = "jsonl")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.