gazetteer: Get geographic coordinates from localities

View source: R/05_gazetteer.R

gazetteerR Documentation

Get geographic coordinates from localities

Description

Extract geographic coordinates from strings containing location names, using an online index. through usage of a gazetteer for Python.

Usage

gazetteer(locality)

Arguments

locality

vector of characters. A vector of location names to process with a gazetteer.

Details

Gazetteers are geographical indexes, with the one used for arete being Nominatim which is accessible through the GeoPy client.

Value

matrix.

See Also

arete_setup

Examples

## Not run: 
example = c("Lisbon", "London")

gazzetteer(example)
## End(Not run)

arete documentation built on Nov. 5, 2025, 6:31 p.m.