install_OCR_packages: Update OCR dependencies

View source: R/01_install_OCR_packages.R

install_OCR_packagesR Documentation

Update OCR dependencies

Description

Install python dependencies needed to run the optional OCR utilities in arete.

Usage

install_OCR_packages(envname = "arete", verbose = TRUE, ...)

Arguments

envname

character. Name or path to the Python virtual environment being used for arete.

verbose

logical. Determines if output should be printed.

...

Other parameters to pass to the installation function as per the documentation of py_install

Value

NULL. If any packages failed to install, a character listing which.

See Also

arete_setup

Examples

## Not run: 
install_OCR_packages("./path/to/venv")

## End(Not run)

arete documentation built on Nov. 5, 2025, 6:31 p.m.