install_python_packages: Update python dependencies

View source: R/01_install_python_packages.R

install_python_packagesR Documentation

Update python dependencies

Description

Install python dependencies needed to run arete.

Usage

install_python_packages(envname, verbose = TRUE, ...)

Arguments

envname

character. Name or path to the Python virtual environment being used for arete.

verbose

logical. Determines if output should be printed.

...

Other parameters to pass to the installation function as per the documentation of py_install

Value

NULL. If any packages failed to install, a character listing which.

See Also

arete_setup

Examples

## Not run: 
install_python_packages("./path/to/venv")

## End(Not run)

arete documentation built on Nov. 5, 2025, 6:31 p.m.