process_species_names: Process and fix species names

View source: R/04_process_species_names.R

process_species_namesR Documentation

Process and fix species names

Description

This function standardizes species names and fixes a number of common typos and mistakes that commonly occur due to OCR.

Usage

process_species_names(species, processing = "all", enforce = FALSE)

Arguments

species

character. String with the name of the species to be processed.

processing

character. One of "trim", "sp nov", "hyphen broken", "abbreviate", "spacing" and "all". By default set to "all", performing every edit.

enforce

boolean. Remove non-conforming entries before returning.

Value

character. A string with the standardized species name.

Examples

process_species_names("macro - thele calpeiana sp. nov.")

arete documentation built on Nov. 5, 2025, 6:31 p.m.