webanno_open: Open a WebAnno TSV v3.3 file.

View source: R/02_webanno_open.R

webanno_openR Documentation

Open a WebAnno TSV v3.3 file.

Description

Read the contents of a WebAnno TSV 3.3 file, a format for annotated text containing named entities and relations.

Usage

webanno_open(path, cut_to_content = FALSE)

Arguments

path

character. A path to a WebAnno TSV v3.3 file.

cut_to_content

logical. Restrict the output file to those sentences containing annotated labels and relations.

Details

One of the format types under use at https://inception-project.github.io/.

Value

WebAnnoTSV. A list of dataframes, each named after the corresponding paragraph in the text.

Examples

example = system.file(paste0("extdata/insecta_annot_1.tsv"), package = "arete")

webanno_open(example)

arete documentation built on Nov. 5, 2025, 6:31 p.m.