webanno_summary: Summarize the contents of a group of WebAnno tsv files

View source: R/02_webanno_summary.R

webanno_summaryR Documentation

Summarize the contents of a group of WebAnno tsv files

Description

Returns

Usage

webanno_summary(input, goal = "relations", collected = TRUE, verbose = TRUE)

Arguments

input

list of character or WebAnnoTSV. The contents of WebAnno TSV v3.3 files as created by webanno_open or a set of paths leading to them.

goal

character. One of "labels", "relations" or "all" determining what is summarized.

collected

boolean. Organize the summary under a single dataframe, otherwise a list is returned.

verbose

boolean. Print the final output.

Value

dataframe.

Examples

example = arete_data("annotations")

webanno_summary(example)

arete documentation built on Nov. 5, 2025, 6:31 p.m.