View source: R/01_arete_setup.R
| arete_setup | R Documentation |
arete requires python to use most of its LLM utilities. OCR utilities will by default not be installed as they are not strictly necessary to the usage of the package. If interested please see install_OCR_packages().
We recommend that you install Python before running arete_setup. Usually performed through sudo apt install python3-venv python3-pip python3-dev on linux systems or reticulate::install_python() for other OS.
Some external software might also be needed to successfully install arete's dependencies, including:
GDAL, GEOS, PROJ, netcdf, sqlite3, tbb, see rspatial.github.io/terra
poppler (rpm: poppler-cpp-devel (Fedora, CentOS, RHEL), brew: poppler (MacOS) )
kableExtra (fontconfig, deb:libfontconfig1-dev (Debian, Ubuntu, etc), rpm: fontconfig-devel (Fedora, EPEL), csw: fontconfig_dev (Solaris), brew: freetype (OSX) )
cmake
With some being covered by r-base-dev:
gfortran, libgmp3-dev,
harfbuzz freetype2 fribidi (deb:libharfbuzz-dev libfribidi-dev (Debian, Ubuntu, etc), rpm: harfbuzz-devel fribidi-devel (Fedora, EPEL), brew: harfbuzz fribidi (OSX) )
arete_setup(python = NULL)
python |
character. Path to a python virtual environment in which to use arete. |
A custom virtual environment path may be passed to python but we recommend
leaving it as NULL and using one of the paths found by reticulate.
It is however useful if arete is already setup and you just wish to update its
dependencies.
character. Python path to the virtual environment created.
## Not run:
arete_setup()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.