View source: R/00_auxiliary_functions.R
| aux_string_to_coords | R Documentation |
Mechanically convert character strings containing geographic coordinates and convert to sets of numeric values. Useful as most LLM experience better and more consistent results when asked to return a single string instead of two separate values.
aux_string_to_coords(coord_string)
coord_string |
character. A string containg potential geographic coordinates. |
Will convert all strings to N, W for consistency's sake. Future updates will probably make it a toggle.
list. Contain latitude and longitude as the first and second elements, respectively.
example = "19 ° 34 ’ S 29 ° 10 ° E"
aux_string_to_coords(example)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.