Learn R Programming

arete (version 0.1)

compare_IUCN: Check EOO differences between two sets of coordinates

Description

Calculate EOO for two sets of coordinates for a practical assessment of data proximity.

Usage

compare_IUCN(x, y, plots = TRUE, verbose = TRUE)

Value

list with two values, the percentage of y that is part of the intersection with x and y and the percentage of x that is part of the intersection with x and y

Arguments

x

data.frame. With two columns containing latitude and longitude. Considered during reporting as data from a LLM.

y

data.frame. With the same formatting as x. Considered during reporting as the ground truth.

plots

logical. Determines if plots should be printed.

verbose

logical. Determines if output should be printed.

Details

Extent of occurrence (EOO) is defined as "the area contained within the shortest continuous imaginary boundary which can be drawn to encompass all the known, inferred or projected sites of present occurrence of a taxon, excluding cases of vagrancy"

Examples

Run this code
set_a = matrix(
  c(54.30379, -25.48098, 54.21251,	-25.47146, 59.53277, -20.37448, 55.59712,
 -22.39599, 55.47244, -26.30330, 61.39205,	-21.12364, 56.24010, -24.40347),
 ncol = 2, byrow = TRUE 
)

set_b = matrix(
c(54.30379,	-25.48098, 111.42100,	-19.00400, 54.21251, -25.47146, 59.53277,
  -20.37448, 55.59125, -22.39599, 55.47244,	-26.30330, 61.39205, -21.12364,
   56.24010,	-24.40347),
   ncol = 2, byrow = TRUE
 )

compare_IUCN(set_a, set_b)

Run the code above in your browser using DataLab