| gazetteer | R Documentation |
Extract geographic coordinates from strings containing location names, using an online index. through usage of a gazetteer for Python.
gazetteer(locality)
locality |
vector of characters. A vector of location names to process with a gazetteer. |
Gazetteers are geographical indexes, with the one used for arete being Nominatim which is accessible through the GeoPy client.
matrix.
arete_setup
## Not run:
example = c("Lisbon", "London")
gazzetteer(example)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.