Learn R Programming

arete (version 0.1)

gazetteer: Get geographic coordinates from localities

Description

Extract geographic coordinates from strings containing location names, using an online index. through usage of a gazetteer for Python.

Usage

gazetteer(locality)

Value

matrix.

Arguments

locality

vector of characters. A vector of location names to process with a gazetteer.

Details

Gazetteers are geographical indexes, with the one used for arete being Nominatim which is accessible through the GeoPy client.

See Also

arete_setup

Examples

Run this code
if (FALSE) {
example = c("Lisbon", "London")

gazzetteer(example)}

Run the code above in your browser using DataLab