View source: R/01_install_OCR_packages.R
| install_OCR_packages | R Documentation |
Install python dependencies needed to run the optional OCR utilities in arete.
install_OCR_packages(envname = "arete", verbose = TRUE, ...)
envname |
character. Name or path to the Python virtual environment being used for arete. |
verbose |
logical. Determines if output should be printed. |
... |
Other parameters to pass to the installation function as per the documentation of |
NULL. If any packages failed to install, a character listing which.
arete_setup
## Not run:
install_OCR_packages("./path/to/venv")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.