View source: R/04_process_species_names.R
| process_species_names | R Documentation |
This function standardizes species names and fixes a number of common typos and mistakes that commonly occur due to OCR.
process_species_names(species, processing = "all", enforce = FALSE)
species |
character. String with the name of the species to be processed. |
processing |
character. One of |
enforce |
boolean. Remove non-conforming entries before returning. |
character. A string with the standardized species name.
process_species_names("macro - thele calpeiana sp. nov.")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.