View source: R/02_webanno_open.R
| webanno_open | R Documentation |
Read the contents of a WebAnno TSV 3.3 file, a format for annotated text containing named entities and relations.
webanno_open(path, cut_to_content = FALSE)
path |
character. A path to a WebAnno TSV v3.3 file. |
cut_to_content |
logical. Restrict the output file to those sentences containing annotated labels and relations. |
One of the format types under use at https://inception-project.github.io/.
WebAnnoTSV. A list of dataframes, each named after the corresponding paragraph in the text.
example = system.file(paste0("extdata/insecta_annot_1.tsv"), package = "arete")
webanno_open(example)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.